#!/bin/sh

usage(){
    echo "============================================"
    echo "USAGE:"
    echo "  install_strongswan.sh [install|uninstall|update]"
    echo "      *)install          install package"
    echo "      *)uninstall        uninstall package"
    echo "============================================"
}

install()
{
    rpm -q openssl >/dev/null 2>&1  
    if [ $? -ne 0 ]; then
        yum install openssl -y
        if [ $? -ne 0 ]; then
            echo "install openssl fail"
            exit 1
        fi
    fi

    rpm -q lzo >/dev/null 2>&1
    if [ $? -ne 0 ]; then
        yum install lzo -y
        if [ $? -ne 0 ]; then
            echo "install lzo fail"
            exit 1
        fi
    fi

    rpm -q pam >/dev/null 2>&1
    if [ $? -ne 0 ]; then
        yum install pam -y
        if [ $? -ne 0 ]; then
            echo "install pam fail"
            exit 1
        fi
    fi

    rpm -q lz4 >/dev/null 2>&1
    if [ $? -ne 0 ]; then
        yum install lz4 -y
        if [ $? -ne 0 ]; then
            echo "install lz4 fail"
            exit 1
        fi
    fi

    rpm -q psmisc >/dev/null 2>&1
    if [ $? -ne 0 ]; then
        yum install psmisc -y
        if [ $? -ne 0 ]; then
            echo "install psmisc fail"
            exit 1
        fi
    fi

    rpm -q net-tools >/dev/null 2>&1
    if [ $? -ne 0 ]; then
        yum install net-tools -y
        if [ $? -ne 0 ]; then
            echo "install net-tools fail"
            exit 1
        fi
    fi

    rpm -q libcurl >/dev/null 2>&1
    if [ $? -ne 0 ]; then
        yum install libcurl -y
        if [ $? -ne 0 ]; then
            echo "install libcurl fail"
            exit 1
        fi
    fi
    
    rm -rf /tmp/securelink_tmp/
    mkdir -p /tmp/securelink_tmp/
    if [ -d "/usr/local/securelink/etc" ]; then
        cp -rf /usr/local/securelink/etc /tmp/securelink_tmp/
    fi

    echo "stop securelink service"
    service securelink stop >/dev/null 2>&1

    rpm -Uvh *.rpm
    if [ $? -ne 0 ]; then
        echo "install fail"
        exit 1
    else
        echo "install success"
    fi

    if [ ! -f "/usr/sbin/ifconfig" ]; then
        cp -rf /bin/ifconfig /usr/sbin/ || cp -rf /sbin/ifconfig /usr/sbin/
    fi
	
    if [ ! -f "/usr/sbin/route" ]; then
        cp -rf /bin/route /usr/sbin/ || cp -rf /sbin/route /usr/sbin/
    fi

    if [ -f "/bin/systemctl" ]; then
        /bin/systemctl daemon-reload
    fi
    
    if [ -d "/tmp/securelink_tmp/etc" ]; then
        cp -rf /tmp/securelink_tmp/etc /usr/local/securelink/
        # /etc/init.d/securelink restart
    fi
    exit 0
}

uninstall()
{
    echo "stop securelink service"
    service securelink stop >/dev/null 2>&1

    rpm -e securelink  >/dev/null 2>&1
    if [ $? -ne 0 ]; then
        echo "uninstall fail"
        exit 1
    else
        echo "uninstall success"
        exit 0
    fi
}

case $1 in
    install)
        install
    ;;

    uninstall)
        uninstall
    ;;

    *)
        usage
        ;;
esac

exit 0